pygeai.core package
===================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pygeai.core.base
   pygeai.core.common
   pygeai.core.embeddings
   pygeai.core.feedback
   pygeai.core.files
   pygeai.core.llm
   pygeai.core.omni
   pygeai.core.plugins
   pygeai.core.rerank
   pygeai.core.secrets
   pygeai.core.services
   pygeai.core.utils

Submodules
----------

pygeai.core.handlers module
---------------------------

.. automodule:: pygeai.core.handlers
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.core.models module
-------------------------

.. automodule:: pygeai.core.models
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.core.responses module
----------------------------

.. automodule:: pygeai.core.responses
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.core.singleton module
----------------------------

.. automodule:: pygeai.core.singleton
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: pygeai.core
   :members:
   :show-inheritance:
   :undoc-members:
